@@ -10,4 +10,4 @@ class Request:
         self.__dict__.update(kwargs)
 
     def __repr__(self):
-        return '<espider.Request {}>'.format(self.url)
+        return '<Request {}>'.format(self.url)
